@@ -20,7 +20,7 @@
  * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA
  * 02111-1307, USA.
  *
- * $Id: hash_table.c,v 1.1 2004/03/11 06:20:29 steinm Exp $
+ * $Id: hash_table.c,v 1.2 2005/01/06 20:12:22 steinm Exp $
  *
  ********************************************************************/
 
@@ -234,7 +234,7 @@ static void *ght_malloc(size_t size, void *data)
 /* Free memory */
 static void ght_free(void *ptr, void *data)
 {
-	return(free(ptr));
+	free(ptr);
 }
 
 /* --- Exported methods --- */
