@@ -32,5 +32,5 @@ ENCODING inputencoding = {
 	 "Oslash", "Ugrave", "Uacute", "Ucircumflex", "Udieresis", "Yacute", "Thorn", "germandbls",
 	 "agrave", "aacute", "acircumflex", "atilde", "adieresis", "aring", "ae", "ccedilla",
 	 "egrave", "eacute", "ecircumflex", "edieresis", "igrave", "iacute", "icircumflex", "idieresis",
-	 "eth", "ntilde", "ograve", "", "oacute", "ocircumflex", "odieresis", "divide",
+	 "eth", "ntilde", "ograve", "oacute", "ocircumflex", "otilde", "odieresis", "divide",
 	 "oslash", "ugrave", "uacute", "ucircumflex", "udieresis", "yacute", "thorn", "ydieresis" } } ;
