@@ -150,6 +150,8 @@ struct adobefontmetric_ {
 	double newslant ;
 };
 
+typedef struct PSColor_ PSColor;
+
 typedef struct PSImage_ PSImage;
 
 struct PSImage_ {
@@ -162,7 +164,11 @@ struct PSImage_ {
 	int height;
 	int components;
 	int bpc;
-	int color_type;
+	int colorspace;
+	ps_bool ismask;
+	PSColor *palette;
+	int numcolors;
+	PSImage *imagemask; // Use other image a s mask for this image
 };
 
 typedef struct PSFont_ PSFont;
@@ -194,6 +200,7 @@ struct PSPattern_ {
 #define PS_COLORSPACE_CMYK    3
 #define PS_COLORSPACE_SPOT    4
 #define PS_COLORSPACE_PATTERN 5
+#define PS_COLORSPACE_INDEXED 6
 
 #define PS_COLORTYPE_FILL   1
 #define PS_COLORTYPE_STROKE 2
@@ -210,8 +217,6 @@ struct PSSpotColor_ {
 	float c4;
 };
 
-typedef struct PSColor_ PSColor;
-
 struct PSColor_ {
 	int colorspace;
 	int prevcolorspace;  // The last colorspace used for pattern of type 1
@@ -440,7 +445,7 @@ void ps_del_resources(PSDoc *psdoc);
 void ps_del_parameters(PSDoc *psdoc);
 void ps_del_values(PSDoc *psdoc);
 void ps_del_bookmarks(PSDoc *psdoc, DLIST *bookmarks);
-int ps_check_for_lig(ADOBEFONTMETRIC *metrics, ADOBEINFO *ai, const char *text, char **newadobename, int *offset);
+int ps_check_for_lig(ADOBEFONTMETRIC *metrics, ADOBEINFO *ai, const char *text, char ligdischar, char **newadobename, int *offset);
 ght_hash_table_t *ps_build_enc_hash(PSDoc *psdoc, ENCODING *enc);
 ght_hash_table_t *ps_build_enc_from_font(PSDoc *psdoc, ADOBEFONTMETRIC *metrics);
 ENCODING *ps_build_enc_vector(PSDoc *psdoc, ght_hash_table_t *hashvec);
